| Title: | Logging for 'dplyr' and 'tidyr' Functions |
|---|---|
| Description: | Provides feedback about 'dplyr' and 'tidyr' operations. |
| Authors: | Benjamin Elbers [aut, cre] (ORCID: <https://orcid.org/0000-0001-5392-3448>), Damiano Oldoni [ctb] (ORCID: <https://orcid.org/0000-0003-3445-7562>) |
| Maintainer: | Benjamin Elbers <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.1.0.9000 |
| Built: | 2026-06-23 16:42:02 UTC |
| Source: | https://github.com/elbersb/tidylog |
Wrapper around dplyr::add_count() that prints information about the operation.
add_count(x, ...)add_count(x, ...)
x |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::add_tally() that prints information about the operation.
add_tally(x, ...)add_tally(x, ...)
x |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::anti_join() that prints information about the operation.
anti_join(x, y, by = NULL, ...)anti_join(x, y, by = NULL, ...)
x, y
|
A pair of data frames, data frame extensions (e.g. a tibble), or lazy data frames (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
by |
A join specification created with If To join on different variables between To join by multiple variables, use a
For simple equality joins, you can alternatively specify a character vector
of variable names to join by. For example, To perform a cross-join, generating all combinations of |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::count() that prints information about the operation.
count(x, ...)count(x, ...)
x |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
See dplyr::count()
Unlike log_...() functions, this assumes the data manipulation
is performed elsewhere and only displays messages.
display_changed_rows(.olddata, .newdata, .funname)display_changed_rows(.olddata, .newdata, .funname)
.olddata |
Data frame before transformation. |
.newdata |
Data frame after transformation. |
.funname |
String: name of function that should be used in messages. |
Wrapper around dplyr::distinct() that prints information about the operation.
distinct(.data, ...)distinct(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::distinct_all() that prints information about the operation.
distinct_all(.tbl, ...)distinct_all(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::distinct_at() that prints information about the operation.
distinct_at(.tbl, ...)distinct_at(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::distinct_if() that prints information about the operation.
distinct_if(.tbl, ...)distinct_if(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around tidyr::drop_na() that prints information about the operation.
drop_na(data, ...)drop_na(data, ...)
data |
A data frame. |
... |
< |
Documentation generated from tidyr version 1.3.2.
See tidyr::drop_na()
Wrapper around tidyr::fill() that prints information about the operation.
fill(data, ...)fill(data, ...)
data |
A data frame. |
... |
Arguments passed on to
|
Documentation generated from tidyr version 1.3.2.
See tidyr::fill()
Wrapper around dplyr::filter() that prints information about the operation.
filter(.data, ...)filter(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
See dplyr::filter()
Wrapper around dplyr::filter_all() that prints information about the operation.
filter_all(.tbl, ...)filter_all(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::filter_at() that prints information about the operation.
filter_at(.tbl, ...)filter_at(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::filter_if() that prints information about the operation.
filter_if(.tbl, ...)filter_if(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::filter_out() that prints information about the operation.
filter_out(.data, ...)filter_out(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::full_join() that prints information about the operation.
full_join(x, y, by = NULL, ...)full_join(x, y, by = NULL, ...)
x, y
|
A pair of data frames, data frame extensions (e.g. a tibble), or lazy data frames (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
by |
A join specification created with If To join on different variables between To join by multiple variables, use a
For simple equality joins, you can alternatively specify a character vector
of variable names to join by. For example, To perform a cross-join, generating all combinations of |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around tidyr::gather() that prints information about the operation.
gather(data, ...)gather(data, ...)
data |
A data frame. |
... |
Arguments passed on to
|
Documentation generated from tidyr version 1.3.2.
See tidyr::gather()
Wrapper around dplyr::group_by() that prints information about the operation.
group_by(.data, ...)group_by(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::group_by_all() that prints information about the operation.
group_by_all(.tbl, ...)group_by_all(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::group_by_at() that prints information about the operation.
group_by_at(.tbl, ...)group_by_at(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::group_by_if() that prints information about the operation.
group_by_if(.tbl, ...)group_by_if(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::inner_join() that prints information about the operation.
inner_join(x, y, by = NULL, ...)inner_join(x, y, by = NULL, ...)
x, y
|
A pair of data frames, data frame extensions (e.g. a tibble), or lazy data frames (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
by |
A join specification created with If To join on different variables between To join by multiple variables, use a
For simple equality joins, you can alternatively specify a character vector
of variable names to join by. For example, To perform a cross-join, generating all combinations of |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::left_join() that prints information about the operation.
left_join(x, y, by = NULL, ...)left_join(x, y, by = NULL, ...)
x, y
|
A pair of data frames, data frame extensions (e.g. a tibble), or lazy data frames (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
by |
A join specification created with If To join on different variables between To join by multiple variables, use a
For simple equality joins, you can alternatively specify a character vector
of variable names to join by. For example, To perform a cross-join, generating all combinations of |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::mutate() that prints information about the operation.
mutate(.data, ...)mutate(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
See dplyr::mutate()
Wrapper around dplyr::mutate_all() that prints information about the operation.
mutate_all(.tbl, ...)mutate_all(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::mutate_at() that prints information about the operation.
mutate_at(.tbl, ...)mutate_at(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::mutate_if() that prints information about the operation.
mutate_if(.tbl, ...)mutate_if(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around tidyr::pivot_longer() that prints information about the operation.
pivot_longer(data, ...)pivot_longer(data, ...)
data |
A data frame to pivot. |
... |
Arguments passed on to
|
Documentation generated from tidyr version 1.3.2.
Wrapper around tidyr::pivot_wider() that prints information about the operation.
pivot_wider(data, ...)pivot_wider(data, ...)
data |
A data frame to pivot. |
... |
Arguments passed on to
|
Documentation generated from tidyr version 1.3.2.
Wrapper around dplyr::relocate() that prints information about the operation.
relocate(.data, ...)relocate(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::rename() that prints information about the operation.
rename(.data, ...)rename(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
See dplyr::rename()
Wrapper around dplyr::rename_all() that prints information about the operation.
rename_all(.tbl, ...)rename_all(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::rename_at() that prints information about the operation.
rename_at(.tbl, ...)rename_at(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::rename_if() that prints information about the operation.
rename_if(.tbl, ...)rename_if(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::rename_with() that prints information about the operation.
rename_with(.data, ...)rename_with(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around tidyr::replace_na() that prints information about the operation.
replace_na(data, ...)replace_na(data, ...)
data |
A data frame or vector. |
... |
Arguments passed on to
|
Documentation generated from tidyr version 1.3.2.
Wrapper around dplyr::right_join() that prints information about the operation.
right_join(x, y, by = NULL, ...)right_join(x, y, by = NULL, ...)
x, y
|
A pair of data frames, data frame extensions (e.g. a tibble), or lazy data frames (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
by |
A join specification created with If To join on different variables between To join by multiple variables, use a
For simple equality joins, you can alternatively specify a character vector
of variable names to join by. For example, To perform a cross-join, generating all combinations of |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::sample_frac() that prints information about the operation.
sample_frac(tbl, ...)sample_frac(tbl, ...)
tbl |
A data.frame. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::sample_n() that prints information about the operation.
sample_n(tbl, ...)sample_n(tbl, ...)
tbl |
A data.frame. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::select() that prints information about the operation.
select(.data, ...)select(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
< |
Documentation generated from dplyr version 1.2.1.
See dplyr::select()
Wrapper around dplyr::select_all() that prints information about the operation.
select_all(.tbl, ...)select_all(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::select_at() that prints information about the operation.
select_at(.tbl, ...)select_at(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::select_if() that prints information about the operation.
select_if(.tbl, ...)select_if(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::semi_join() that prints information about the operation.
semi_join(x, y, by = NULL, ...)semi_join(x, y, by = NULL, ...)
x, y
|
A pair of data frames, data frame extensions (e.g. a tibble), or lazy data frames (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
by |
A join specification created with If To join on different variables between To join by multiple variables, use a
For simple equality joins, you can alternatively specify a character vector
of variable names to join by. For example, To perform a cross-join, generating all combinations of |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around tidyr::separate_wider_delim() that prints information about the operation.
separate_wider_delim(data, ...)separate_wider_delim(data, ...)
data |
A data frame. |
... |
Arguments passed on to
|
Documentation generated from tidyr version 1.3.2.
See tidyr::separate_wider_delim()
Wrapper around tidyr::separate_wider_position() that prints information about the operation.
separate_wider_position(data, ...)separate_wider_position(data, ...)
data |
A data frame. |
... |
Arguments passed on to
|
Documentation generated from tidyr version 1.3.2.
See tidyr::separate_wider_position()
tidyr::separate_wider_position()
Wrapper around tidyr::separate_wider_regex() that prints information about the operation.
separate_wider_regex(data, ...)separate_wider_regex(data, ...)
data |
A data frame. |
... |
Arguments passed on to
|
Documentation generated from tidyr version 1.3.2.
See tidyr::separate_wider_regex()
Wrapper around dplyr::slice() that prints information about the operation.
slice(.data, ...)slice(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
See dplyr::slice()
Wrapper around dplyr::slice_head() that prints information about the operation.
slice_head(.data, ...)slice_head(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::slice_max() that prints information about the operation.
slice_max(.data, ...)slice_max(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::slice_min() that prints information about the operation.
slice_min(.data, ...)slice_min(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::slice_sample() that prints information about the operation.
slice_sample(.data, ...)slice_sample(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::slice_tail() that prints information about the operation.
slice_tail(.data, ...)slice_tail(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around tidyr::spread() that prints information about the operation.
spread(data, ...)spread(data, ...)
data |
A data frame. |
... |
Arguments passed on to
|
Documentation generated from tidyr version 1.3.2.
See tidyr::spread()
Wrapper around dplyr::summarise() that prints information about the operation.
summarise(.data, ...)summarise(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::summarise_all() that prints information about the operation.
summarise_all(.tbl, ...)summarise_all(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::summarise_at() that prints information about the operation.
summarise_at(.tbl, ...)summarise_at(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::summarise_if() that prints information about the operation.
summarise_if(.tbl, ...)summarise_if(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::summarize() that prints information about the operation.
summarize(.data, ...)summarize(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::summarize_all() that prints information about the operation.
summarize_all(.tbl, ...)summarize_all(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::summarize_at() that prints information about the operation.
summarize_at(.tbl, ...)summarize_at(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::summarize_if() that prints information about the operation.
summarize_if(.tbl, ...)summarize_if(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::tally() that prints information about the operation.
tally(x, ...)tally(x, ...)
x |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
See dplyr::tally()
outputs some information about the data frame/tbl
tidylog(.data)tidylog(.data)
.data |
a tbl/data frame |
same as .data
tidylog(mtcars) #> tidylog: data.frame with 32 rows and 11 columnstidylog(mtcars) #> tidylog: data.frame with 32 rows and 11 columns
Wrapper around dplyr::top_frac() that prints information about the operation.
top_frac(x, ...)top_frac(x, ...)
x |
A data frame. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::top_n() that prints information about the operation.
top_n(x, ...)top_n(x, ...)
x |
A data frame. |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
See dplyr::top_n()
Wrapper around dplyr::transmute() that prints information about the operation.
transmute(.data, ...)transmute(.data, ...)
.data |
A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details. |
... |
< The value can be:
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::transmute_all() that prints information about the operation.
transmute_all(.tbl, ...)transmute_all(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::transmute_at() that prints information about the operation.
transmute_at(.tbl, ...)transmute_at(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around dplyr::transmute_if() that prints information about the operation.
transmute_if(.tbl, ...)transmute_if(.tbl, ...)
.tbl |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
Wrapper around tidyr::uncount() that prints information about the operation.
uncount(data, ...)uncount(data, ...)
data |
A data frame, tibble, or grouped tibble. |
... |
Arguments passed on to
|
Documentation generated from tidyr version 1.3.2.
See tidyr::uncount()
Wrapper around dplyr::ungroup() that prints information about the operation.
ungroup(x, ...)ungroup(x, ...)
x |
A |
... |
Arguments passed on to
|
Documentation generated from dplyr version 1.2.1.
See dplyr::ungroup()