| Title: | Logging for 'dplyr' and 'tidyr' Functions |
|---|---|
| Description: | Provides feedback about 'dplyr' and 'tidyr' operations. |
| Authors: | Benjamin Elbers [aut, cre] (ORCID: <https://orcid.org/0000-0001-5392-3448>), Damiano Oldoni [ctb] (ORCID: <https://orcid.org/0000-0003-3445-7562>) |
| Maintainer: | Benjamin Elbers <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.1.0.9000 |
| Built: | 2026-06-03 13:58:18 UTC |
| Source: | https://github.com/elbersb/tidylog |
Wrapper around dplyr::add_count that prints information about the operation
add_count(x, ...)add_count(x, ...)
x |
see add_count |
... |
see add_count |
see add_count
Wrapper around dplyr::add_tally that prints information about the operation
add_tally(x, ...)add_tally(x, ...)
x |
see add_tally |
... |
see add_tally |
see add_tally
Wrapper around dplyr::anti_join that prints information about the operation
anti_join(x, y, by, ...)anti_join(x, y, by, ...)
x |
see anti_join |
y |
see anti_join |
by |
see anti_join |
... |
see anti_join |
see anti_join
Wrapper around dplyr::count that prints information about the operation
count(x, ...)count(x, ...)
x |
see count |
... |
see count |
see count
Unlike 'log_...()' functions, this assumes the data manipulation is performed elsewhere and only displays messages.
display_changed_rows(.olddata, .newdata, .funname)display_changed_rows(.olddata, .newdata, .funname)
.olddata |
Data frame before transformation. |
.newdata |
Data frame after transformation. |
.funname |
String: name of function that should be used in messages. |
Wrapper around dplyr::distinct that prints information about the operation
distinct(.data, ...)distinct(.data, ...)
.data |
see distinct |
... |
see distinct |
see distinct
Wrapper around dplyr::distinct_all that prints information about the operation
distinct_all(.tbl, ...)distinct_all(.tbl, ...)
.tbl |
see distinct_all |
... |
see distinct_all |
see distinct_all
Wrapper around dplyr::distinct_at that prints information about the operation
distinct_at(.tbl, ...)distinct_at(.tbl, ...)
.tbl |
see distinct_at |
... |
see distinct_at |
see distinct_at
Wrapper around dplyr::distinct_if that prints information about the operation
distinct_if(.tbl, ...)distinct_if(.tbl, ...)
.tbl |
see distinct_if |
... |
see distinct_if |
see distinct_if
Wrapper around tidyr::drop_na that prints information about the operation
drop_na(data, ...)drop_na(data, ...)
data |
see drop_na |
... |
see drop_na |
see drop_na
Wrapper around tidyr::fill that prints information about the operation
fill(data, ...)fill(data, ...)
data |
see fill |
... |
see fill |
see fill
Wrapper around dplyr::filter that prints information about the operation
filter(.data, ...)filter(.data, ...)
.data |
see filter |
... |
see filter |
see filter
Wrapper around dplyr::filter_all that prints information about the operation
filter_all(.tbl, ...)filter_all(.tbl, ...)
.tbl |
see filter_all |
... |
see filter_all |
see filter_all
Wrapper around dplyr::filter_at that prints information about the operation
filter_at(.tbl, ...)filter_at(.tbl, ...)
.tbl |
see filter_at |
... |
see filter_at |
see filter_at
Wrapper around dplyr::filter_if that prints information about the operation
filter_if(.tbl, ...)filter_if(.tbl, ...)
.tbl |
see filter_if |
... |
see filter_if |
see filter_if
Wrapper around dplyr::full_join that prints information about the operation
full_join(x, y, by, ...)full_join(x, y, by, ...)
x |
see full_join |
y |
see full_join |
by |
see full_join |
... |
see full_join |
see full_join
Wrapper around tidyr::gather that prints information about the operation
gather(data, ...)gather(data, ...)
data |
see gather |
... |
see gather |
see gather
Wrapper around dplyr::group_by that prints information about the operation
group_by(.data, ...)group_by(.data, ...)
.data |
see group_by |
... |
see group_by |
see group_by
Wrapper around dplyr::group_by_all that prints information about the operation
group_by_all(.tbl, ...)group_by_all(.tbl, ...)
.tbl |
see group_by_all |
... |
see group_by_all |
see group_by_all
Wrapper around dplyr::group_by_at that prints information about the operation
group_by_at(.tbl, ...)group_by_at(.tbl, ...)
.tbl |
see group_by_at |
... |
see group_by_at |
see group_by_at
Wrapper around dplyr::group_by_if that prints information about the operation
group_by_if(.tbl, ...)group_by_if(.tbl, ...)
.tbl |
see group_by_if |
... |
see group_by_if |
see group_by_if
Wrapper around dplyr::inner_join that prints information about the operation
inner_join(x, y, by, ...)inner_join(x, y, by, ...)
x |
see inner_join |
y |
see inner_join |
by |
see inner_join |
... |
see inner_join |
see inner_join
Wrapper around dplyr::left_join that prints information about the operation
left_join(x, y, by, ...)left_join(x, y, by, ...)
x |
see left_join |
y |
see left_join |
by |
see left_join |
... |
see left_join |
see left_join
Wrapper around dplyr::mutate that prints information about the operation
mutate(.data, ...)mutate(.data, ...)
.data |
see mutate |
... |
see mutate |
see mutate
Wrapper around dplyr::mutate_all that prints information about the operation
mutate_all(.tbl, ...)mutate_all(.tbl, ...)
.tbl |
see mutate_all |
... |
see mutate_all |
see mutate_all
Wrapper around dplyr::mutate_at that prints information about the operation
mutate_at(.tbl, ...)mutate_at(.tbl, ...)
.tbl |
see mutate_at |
... |
see mutate_at |
see mutate_at
Wrapper around dplyr::mutate_if that prints information about the operation
mutate_if(.tbl, ...)mutate_if(.tbl, ...)
.tbl |
see mutate_if |
... |
see mutate_if |
see mutate_if
Wrapper around tidyr::pivot_longer that prints information about the operation
pivot_longer(data, ...)pivot_longer(data, ...)
data |
see pivot_longer |
... |
see pivot_longer |
see pivot_longer
Wrapper around tidyr::pivot_wider that prints information about the operation
pivot_wider(data, ...)pivot_wider(data, ...)
data |
see pivot_wider |
... |
see pivot_wider |
see pivot_wider
Wrapper around dplyr::relocate that prints information about the operation
relocate(.data, ...)relocate(.data, ...)
.data |
see relocate |
... |
see relocate |
see relocate
Wrapper around dplyr::rename that prints information about the operation
rename(.data, ...)rename(.data, ...)
.data |
see rename |
... |
see rename |
see rename
Wrapper around dplyr::rename_all that prints information about the operation
rename_all(.tbl, ...)rename_all(.tbl, ...)
.tbl |
see rename_all |
... |
see rename_all |
see rename_all
Wrapper around dplyr::rename_at that prints information about the operation
rename_at(.tbl, ...)rename_at(.tbl, ...)
.tbl |
see rename_at |
... |
see rename_at |
see rename_at
Wrapper around dplyr::rename_if that prints information about the operation
rename_if(.tbl, ...)rename_if(.tbl, ...)
.tbl |
see rename_if |
... |
see rename_if |
see rename_if
Wrapper around dplyr::rename_with that prints information about the operation
rename_with(.data, ...)rename_with(.data, ...)
.data |
see rename_with |
... |
see rename_with |
see rename_with
Wrapper around tidyr::replace_na that prints information about the operation
replace_na(data, ...)replace_na(data, ...)
data |
see replace_na |
... |
see replace_na |
see replace_na
Wrapper around dplyr::right_join that prints information about the operation
right_join(x, y, by, ...)right_join(x, y, by, ...)
x |
see right_join |
y |
see right_join |
by |
see right_join |
... |
see right_join |
see right_join
Wrapper around dplyr::sample_frac that prints information about the operation
sample_frac(tbl, ...)sample_frac(tbl, ...)
tbl |
see sample_frac |
... |
see sample_frac |
see sample_frac
Wrapper around dplyr::sample_n that prints information about the operation
sample_n(tbl, ...)sample_n(tbl, ...)
tbl |
see sample_n |
... |
see sample_n |
see sample_n
Wrapper around dplyr::select that prints information about the operation
select(.data, ...)select(.data, ...)
.data |
see select |
... |
see select |
see select
Wrapper around dplyr::select_all that prints information about the operation
select_all(.tbl, ...)select_all(.tbl, ...)
.tbl |
see select_all |
... |
see select_all |
see select_all
Wrapper around dplyr::select_at that prints information about the operation
select_at(.tbl, ...)select_at(.tbl, ...)
.tbl |
see select_at |
... |
see select_at |
see select_at
Wrapper around dplyr::select_if that prints information about the operation
select_if(.tbl, ...)select_if(.tbl, ...)
.tbl |
see select_if |
... |
see select_if |
see select_if
Wrapper around dplyr::semi_join that prints information about the operation
semi_join(x, y, by, ...)semi_join(x, y, by, ...)
x |
see semi_join |
y |
see semi_join |
by |
see semi_join |
... |
see semi_join |
see semi_join
Wrapper around tidyr::separate_wider_delim that prints information about the operation
separate_wider_delim(data, ...)separate_wider_delim(data, ...)
data |
|
... |
Wrapper around tidyr::separate_wider_position that prints information about the operation
separate_wider_position(data, ...)separate_wider_position(data, ...)
data |
|
... |
Wrapper around tidyr::separate_wider_regex that prints information about the operation
separate_wider_regex(data, ...)separate_wider_regex(data, ...)
data |
|
... |
Wrapper around dplyr::slice that prints information about the operation
slice(.data, ...)slice(.data, ...)
.data |
see slice |
... |
see slice |
see slice
Wrapper around dplyr::slice_head that prints information about the operation
slice_head(.data, ...)slice_head(.data, ...)
.data |
see slice_head |
... |
see slice_head |
see slice_head
Wrapper around dplyr::slice_max that prints information about the operation
slice_max(.data, ...)slice_max(.data, ...)
.data |
see slice_max |
... |
see slice_max |
see slice_max
Wrapper around dplyr::slice_min that prints information about the operation
slice_min(.data, ...)slice_min(.data, ...)
.data |
see slice_min |
... |
see slice_min |
see slice_min
Wrapper around dplyr::slice_sample that prints information about the operation
slice_sample(.data, ...)slice_sample(.data, ...)
.data |
see slice_sample |
... |
see slice_sample |
see slice_sample
Wrapper around dplyr::slice_tail that prints information about the operation
slice_tail(.data, ...)slice_tail(.data, ...)
.data |
see slice_tail |
... |
see slice_tail |
see slice_tail
Wrapper around tidyr::spread that prints information about the operation
spread(data, ...)spread(data, ...)
data |
see spread |
... |
see spread |
see spread
Wrapper around dplyr::summarise that prints information about the operation
summarise(.data, ...)summarise(.data, ...)
.data |
see summarise |
... |
see summarise |
see summarise
Wrapper around dplyr::summarise_all that prints information about the operation
summarise_all(.tbl, ...)summarise_all(.tbl, ...)
.tbl |
see summarise_all |
... |
see summarise_all |
see summarise_all
Wrapper around dplyr::summarise_at that prints information about the operation
summarise_at(.tbl, ...)summarise_at(.tbl, ...)
.tbl |
see summarise_at |
... |
see summarise_at |
see summarise_at
Wrapper around dplyr::summarise_if that prints information about the operation
summarise_if(.tbl, ...)summarise_if(.tbl, ...)
.tbl |
see summarise_if |
... |
see summarise_if |
see summarise_if
Wrapper around dplyr::summarize that prints information about the operation
summarize(.data, ...)summarize(.data, ...)
.data |
see summarize |
... |
see summarize |
see summarize
Wrapper around dplyr::summarize_all that prints information about the operation
summarize_all(.tbl, ...)summarize_all(.tbl, ...)
.tbl |
see summarize_all |
... |
see summarize_all |
see summarize_all
Wrapper around dplyr::summarize_at that prints information about the operation
summarize_at(.tbl, ...)summarize_at(.tbl, ...)
.tbl |
see summarize_at |
... |
see summarize_at |
see summarize_at
Wrapper around dplyr::summarize_if that prints information about the operation
summarize_if(.tbl, ...)summarize_if(.tbl, ...)
.tbl |
see summarize_if |
... |
see summarize_if |
see summarize_if
Wrapper around dplyr::tally that prints information about the operation
tally(x, ...)tally(x, ...)
x |
see tally |
... |
see tally |
see tally
outputs some information about the data frame/tbl
tidylog(.data)tidylog(.data)
.data |
a tbl/data frame |
same as .data
tidylog(mtcars) #> tidylog: data.frame with 32 rows and 11 columnstidylog(mtcars) #> tidylog: data.frame with 32 rows and 11 columns
Wrapper around dplyr::top_frac that prints information about the operation
top_frac(x, ...)top_frac(x, ...)
x |
see top_frac |
... |
see top_frac |
see top_frac
Wrapper around dplyr::top_n that prints information about the operation
top_n(x, ...)top_n(x, ...)
x |
see top_n |
... |
see top_n |
see top_n
Wrapper around dplyr::transmute that prints information about the operation
transmute(.data, ...)transmute(.data, ...)
.data |
see transmute |
... |
see transmute |
see transmute
Wrapper around dplyr::transmute_all that prints information about the operation
transmute_all(.tbl, ...)transmute_all(.tbl, ...)
.tbl |
see transmute_all |
... |
see transmute_all |
see transmute_all
Wrapper around dplyr::transmute_at that prints information about the operation
transmute_at(.tbl, ...)transmute_at(.tbl, ...)
.tbl |
see transmute_at |
... |
see transmute_at |
see transmute_at
Wrapper around dplyr::transmute_if that prints information about the operation
transmute_if(.tbl, ...)transmute_if(.tbl, ...)
.tbl |
see transmute_if |
... |
see transmute_if |
see transmute_if
Wrapper around tidyr::uncount that prints information about the operation
uncount(data, ...)uncount(data, ...)
data |
see uncount |
... |
see uncount |
see uncount
Wrapper around dplyr::ungroup that prints information about the operation
ungroup(x, ...)ungroup(x, ...)
x |
see ungroup |
... |
see ungroup |
see ungroup